rm(list=ls())
library(reshape2)
library(base)
library(ggplot2)
library(grid)
library(tikzDevice)
library(stringr)
library(tidyverse)

  #--------------------------------
  # Figure 2: Children Ever Born
  #--------------------------------
 
  setwd("../ReplicationPackage/Figure_02/")

  dat <- read.table("Figure2.txt", 
                    sep="\t",
                    header = TRUE)

  dat$cohort <- factor(dat$cohort,  levels=c("1828","1848","1868","1888","1908","1928","1948"))
  dat <- subset(dat, !is.na(cohort))
 
  lineplot <- ggplot(data=dat, aes(x=inc, y=ceb, group=cohort, colour = cohort)) + 
    geom_line(size=1.) + 
    geom_point(size=1.5)+
    theme_bw()+
    ylab(" ")+
    xlab(" ") +
    scale_color_manual(values=c('#cac27e',
                                '#6e8e84',
                                '#e37e00',
                                '#938dd2',
                                '#006000',
                                '#1a476f',
                                '#c10534'),name="", labels = c("1828","1848","1868","1888","1908","1928","1948")) +
    scale_x_continuous(breaks=c(0,10000,20000,30000,40000,50000,60000,70000), labels = c("0","10,000","20,000","30,000","40,000","50,000","60,000","70,000"))+
    theme(legend.title = element_blank(),
          legend.text = element_text(size=9,margin = margin(r = 15, unit = "pt")),
          legend.position = "bottom",
          axis.text.x = element_text(size=9, vjust=-1),
          axis.text.y=element_text(size=9),
          axis.title.y=element_blank(),
          axis.title.x=element_text(size=9),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"))+
    guides(col = guide_legend(nrow = 1))
 
  ggsave("Figure2.pdf",height=3.5, width=6)
  
  print(lineplot)
  dev.off()
  
  #-------------
  # end of file
  #-------------
