rm(list=ls())
library(reshape2)
library(scales)
library(xtable) 
library(base)
library(ggplot2)
library(grid)
library(tikzDevice)
library(tidyverse)
library(lubridate)
library(tidyr)
 
#----------------------------------
# Figure 3: TFR and GDP pc in 1970
#----------------------------------

setwd("../ReplicationPackage/Figure_03/")

# 1. Load WDI data

# 1970
dat <- read.table("Figure3.txt", 
                  sep="\t",
                  header = TRUE)


dat <- dat %>% drop_na(ln_gdp_1970, tfr_1970)
dat<-dat[!(dat$country_code=="NAC"),]

vpos <- c(-0.25,-0.50,-0.25,-1.20,-0.25,-0.05, 1.25,-1.75,-0.40, 1.85,
          1.25,-0.25,-0.25,-1.00, 1.00, 1.10, 1.35, 1.75,-0.25, 1.00,
          -0.50, 1.85,-0.25,-0.25,-0.25, 1.00, 1.00,-0.25,-0.75,-0.25,
          -0.25,-0.25,-0.75,-0.25, 1.25,-0.25,-0.50,-0.75,-0.25,-0.25,
          -0.25,-0.25,-0.25,-0.25,-0.25, 0.25, 0.25, 1.00,-0.25,-0.25,
          1.00,-0.25,-0.25,-0.25, 1.10, 1.25,-0.25,-0.25,-0.25,-0.25,
          1.00,-0.75,-0.75, 1.00,-0.25, 1.00,-1.00,-0.25,-0.75,-0.25,
          1.00, 1.05, 0.25,-0.25,-0.25,-0.75)

hpos <- c(-0.25,-0.25,-0.25, 0.25,-0.25,-0.25, 1.25,-0.25,-0.25, 0.50,
          -0.25,-0.25,-0.25, 1.00, 1.25,-0.25,-0.25, 0.65,-0.25,-0.25,
          -0.25, 0.25,-0.25,-0.25,-0.25,-0.50,-0.25,-0.25,-0.25,-0.25,
          -0.25,-0.25, 0.80,-0.25,-0.25,-0.25,-0.25, 1.00,-0.25,-0.25,
          -0.25,-0.25,-0.25,-0.25,-0.25,-0.25,-0.75,-0.25,-0.25,-0.25,
          -0.25,-0.25,-0.25,-0.25,-0.25, 1.25, 1.25,-0.25,-0.25,-0.25,
          -0.25, 0.50, 1.00, 1.25,-0.25,-0.50, 0.50,-0.25, 0.50, 1.25,
          1.25,-0.50, 1.25,-0.25,-0.25, 0.50)
 
lineplot <- ggplot(data=dat, aes(x=ln_gdp_1970, y=tfr_1970)) + 
  geom_point(size=2, color="#4040bf") +
  geom_text(aes(label=country_code, color="#4040bf"), size=2.25, vjust=vpos, hjust=hpos) +
  theme(panel.spacing = unit(0, "lines"), 
        strip.background = element_blank()) +
  theme_bw()+
  ylab("Total Fertility Rate")+
  xlab("GDP per capita  (constant 2010 USD)")+
  scale_color_manual(values=c("#4040bf")) +  
  scale_x_continuous(breaks=c(0,log(1000),log(10000), log(100000)), labels=c("0","1,000","10,000","100,000"), limits=c(5, log(100000))) +
  theme(legend.position = "none",
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.x = element_text(size=9, hjust=0.6),
        axis.text.y=element_text(size=9),
        axis.title.y=element_text(size=9),
        axis.title.x=element_text(size=9))

ggsave("Figure3.pdf",height=3.0, width=6)   

#-------------
# end of file
#-------------

