* ---------------------------------------------------------------------------- *
* 							Figure 5b - CPS ASEC							   *
* ---------------------------------------------------------------------------- *
* author: 		 Anne Hannusch
* last modified: 2023-02-14

* This code computes female labor force participation by marital status  
* between 1963-2018.

* Raw data can be downloaded from IPUMS CPS: https://cps.ipums.org/
* ---------------------------------------------------------------------------- *

global PATH   = "../ReplicationPackage/Figure_05"

use "${PATH}/cps_00056.dta", clear

* ---------------------------------------------------------------------------- *
* A. Create Variables 														   *
* ---------------------------------------------------------------------------- *

gen married=.
replace married=1 if marst==1 | marst==2 & sex==2
replace married=0 if marst==6 & sex==2

label define marriedl 0 "single" 1 "married"
label values married marriedl

gen flfp_tot=.
replace flfp_tot=1 if labforce==2 & (marst==1| marst==2| marst==6) & sex==2
replace flfp_tot=0 if labforce==1 & (marst==1| marst==2| marst==6) & sex==2

gen flfp_mar=.
replace flfp_mar=1 if labforce==2 & (marst==1| marst==2) & sex==2
replace flfp_mar=0 if labforce==1 & (marst==1| marst==2) & sex==2


gen flfp_sgl=.
replace flfp_sgl=1 if labforce==2 & marst==6 & sex==2
replace flfp_sgl=0 if labforce==1 & marst==6 & sex==2

* ---------------------------------------------------------------------------- *
* B. Sample Selection														   *
* ---------------------------------------------------------------------------- *

keep if popstat==1 // adult civilian population
keep if age>=16 // 16+ years
drop if asecwth<0

* ---------------------------------------------------------------------------- *
* C. Female LFP By Marital Status and Year									   *
* ---------------------------------------------------------------------------- *

collapse (mean) flfp_tot flfp_mar flfp_sgl [aw=asecwth], by(year)

export excel "${PATH}/LFP_CPS-ASEC.xlsx", replace

* ---------------------------------------------------------------------------- *
* 								end of do-file								   *
* ---------------------------------------------------------------------------- *
