  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)

  #--------------------------------
  # Figure 7: Total Fertility Rates
  #--------------------------------
  
  setwd("../ReplicationPackage/Figure_07/")
  
  dat <- read.table("Figure7.txt", 
                    sep="\t",
                    header = TRUE)
 
  dat$country <- factor(dat$country, c("AUT","BEL", "DNK", "DEU", "ITA", "JPN", "ESP", "SWE", "CHE", "GBR", "USA"))
  
  df1 <- subset(dat, !is.na(country))
  df1 <- subset(df1, year>1969) 

  labels1 =c("Austria", "Belgium", "Denmark", "Germany", "Italy", "Japan", "Spain", "Sweden", "Switzerland", "UK", "USA")
  
  lineplot <- ggplot(data=df1, aes(x=year, y=tfr,  colour = country)) + 
   geom_line(aes(colour=country), size=1.0) + 
   theme_bw()+
   theme(panel.border = element_blank(), panel.grid.major = element_blank(),
            panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    xlab(" ") +
    xlim(c(1972,2015)) +
    scale_color_manual(values=c('#1a476f',
                                '#90353b',	
                                '#55752f',
                                '#e37e00',
                                '#6e8e84',
                                '#b0b0b0',
                                '#938dd2',
                                '#cac27e',
                                '#a0522d',
                                '#006000',
                                '#c10534') , name="", labels = labels1) +
    scale_y_continuous(breaks=c(1,1.5,2,2.5,3), limits = c(1,3),expand = c(0,0))+
    theme(legend.position = "bottom",
          legend.title = element_blank(),
          legend.text = element_text(size=9),
          legend.spacing.x = unit(0.25, 'cm'),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=9, vjust=-1),
          axis.text.y=element_text(size=9),
          axis.title.y=element_blank(),
          axis.title.x=element_text(size=9),
    )+
    guides(color=guide_legend(nrow=2,byrow=TRUE))
  
  ggsave("Figure7.pdf",height=3.5, width=6)  

  #-------------
  # end of file
  #-------------
