rm(list=ls())
library(reshape2)
library(base)
library(ggplot2)
library(grid)
library(tikzDevice)
library(stringr)
library(tidyverse)

# --------------------------------
# Figure 10: TFR by Group
# --------------------------------

# 1. Load data

setwd("../ReplicationPackage/Figure_10/")

dat <- read.table("Figure10.txt", 
                  sep="\t",
                  header = TRUE)

dat$group <- factor(dat$group,  levels=c("1","2","3"))
dat <- subset(dat, !is.na(tfr))
dat <- subset(dat, !is.na(group))

lineplot <- ggplot(data=dat, aes(x=time, y=tfr,  colour = group)) + 
  geom_line(,size=1.0) + 
  geom_point(aes(shape=group),size =  2.0) + 
  theme_bw()+
  theme(panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
        axis.title.x=element_text(size=9),
        axis.title.y=element_blank()
  ) +
  ylab(" ")+
  xlab(" ") +
  xlim(c(1972,2015)) +
  scale_color_manual(values=c('#1a476f',
                              '#006000',
                              '#c10534'),name="", labels = c("High", "Medium","Low")) +
  scale_shape_manual(values=c(15,17,19) , name="", labels = c("High", "Medium","Low")) +
  scale_linetype_manual(values=c("longdash", "dash", "solid") , name="", labels = c("High", "Medium","Low")) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        legend.text = element_text(size=9),
        legend.spacing.x = unit(0.25, 'cm'),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.x = element_text(size=9),
        axis.text.y=element_text(size=9),
        axis.title.y=element_text(size=9),
        axis.title.x=element_text(size=9),
        legend.key.width = unit(1.5,"cm")
  )

ggsave("Figure10.pdf",height=3.75, width=6)


print(lineplot)
dev.off()

#-------------
# end of file
#-------------
