  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)

  #--------------------------------
  # Figure 12: OECD TFR and LFR
  #--------------------------------
 
  setwd("../ReplicationPackage/Figure_12/")
  
  # 1980   
  dat <- read.table("Figure12.txt", 
                    sep="\t",
                    header = TRUE)
 
  df1 <- subset(dat, year==1980)  

  df1$label <- factor(df1$label, c("AUS", "CAN", "FIN",	"FRA", "DEU","ITA", "JPN", "NLD", "NOR", "PRT", "ESP", "SWE", "USA"))
  
  vpos <- c(-1, -0.75, 2, -1, 2, 1.0, 0.5, 1.5, 0.9, -0.5, 1, -1, -1)
  hpos <- c(0, 0.25, 1.0, 1, 0.75, 1.25, 1.5,  -0.5, -0.25, -0.25, -0.4, 1, 0.75)
 
  lineplot <- ggplot(data=df1, aes(x=FLFP, y=TFR)) + 
    geom_point(size=1.5, color="#4040bf") +
    geom_smooth(method=lm, level = 0.9, color="#4040bf", size=1.25,  fill=c("#acace6")) +
    geom_text(aes(label=label, color="#4040bf"), size=2.5, vjust=vpos, hjust=hpos) +
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=10),
          axis.title.y=element_blank())+
    ylab(" ")+
    xlab("Female LFP")+
    scale_color_manual(values=c("#4040bf"), name="") +    
    theme(legend.position = "none",
          legend.title = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9))
  
  ggsave("Figure12a.pdf",height=2,width=3) 
  
  
  # 2000 
  df2 <- subset(dat, year==2000)  
  
  df2$label <- factor(df2$label, c("AUS", "CAN", "FIN",	"FRA", "DEU","ITA", "JPN", "NLD", "NOR", "PRT", "ESP", "SWE", "USA"))
  
  vpos <- c(1,-0.25,-1.75,1,-1,-2,-1,-2,-0.75,0.75,1,-0.5,-1)
  hpos <- c(0.5,1.25,1,1,-0.25,1,1.25,0.5,1.25,-0.5,1,-0.25,1.25)

  lineplot <- ggplot(data=df2, aes(x=FLFP, y=TFR)) + 
    geom_point(size=1.5, color="#4040bf") +
    geom_smooth(method=lm, level = 0.9, color="#4040bf", size=1.25,  fill=c("#acace6")) +
    geom_text(aes(label=label, color="#4040bf"), size=2.5, vjust=-vpos, hjust=hpos) +
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank())+
    ylab(" ")+
    xlab("Female LFP")+
    scale_color_manual(values=c("#4040bf"), name="") +   
    theme(legend.position = "none",
          legend.title = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9))
  
  ggsave("Figure12b.pdf",height=2,width=3) 
  
  
  #-------------
  # end of file
  #-------------
