
clear all
set more off


/* Raw data 
https://usa.ipums.org/usa/index.shtml

* US Census samples: 
	- 1980 5% state
	- 1990 5% state
	- 2000 5% 
	- 2010 ACS 5yr
	- 2019 ACS 5yr

* Variables: 
	- year
	- perwt
	- gq
	- nchild
	- yngch
	- sex
	- age 
	- race
	- hispan
	- educd (educ (detailed))
	
Steven Ruggles, Sarah Flood, Ronald Goeken, Megan Schouweiler and Matthew Sobek. IPUMS USA: Version 12.0 [dataset]. Minneapolis, MN: IPUMS, 2022. https://doi.org/10.18128/D010.V12.0
*/

cd ...

* Import raw data 
use "../Census1980-1990-2000-2010-2019.dta", clear

**** Sample selection *****

* Keep women only ...
keep if sex==2

* ... between 24 and 49 ...
keep if age>=24 & age<=49  

* ... in households (drop group quarters)
drop if gq<. & gq~=1

**** create birth dummy *****
gen birth = yngch == 0 if yngch!=.

**** create the "standard" educational groups *****

gen education = 0 if educd<=61
replace education = 1 if educd==60 | educd==62  | educd==63 | educd==64
replace education = 2 if educd<=99 & education==.
replace education = 3 if educd==101 | educd==100 
replace education = 4 if educd<=116 & education==.

	* Age groups
	gen gage = floor(age/5)*5
	
	* Collapse by year, education and age group
	gen n = 1
	collapse (sum) n (mean) birth nchild [w = perwt], by(year education gage)
	
	* Initial fertility rate, first age group, age == 24
	replace birth = nchild  if  gage == 20
	
	* Fertility rate per year times 5 for all other age groups (age group is 5 years)
	replace birth = birth*5 if gage != 20
	
	* Average number of observations
	gen avg_n_cell = n if gage != 20

	* Collapse by year and  education 
	collapse (mean) avg_n_cell (sum) n birth , by(education year) 
	
	* Rename fertility rate variable
	rename birth fr
	
	* Normilize fertility rate variable
	bysort year (education): gen fr_norm = fr/fr[1]
 
outsheet using "../ReplicationPackage/Figure_13/Figure13.txt", replace
