  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  library(RColorBrewer)
  
  #------------------------------------------------------
  # Figure 15: Normalized Hybrid Fertility Rates - Europe
  #------------------------------------------------------
  
  setwd("../ReplicationPackage/Figure_15/")
  
  # 1. Load data
  
  dat <- read.table("Figure15.txt", 
                    sep="\t",
                    header = TRUE)
 
  #--------------------------------
  # DE
  #--------------------------------
  df1 <- subset(dat, country=="DE")  
  df1$education <- as.numeric(df1$education)
 
  vpos <- c(0.25,-0.75, -0.75, -1.25, -1)
  hpos <- c(-0.25,-0.25,-0.25,0.25,0.5)

  lineplot <- ggplot(data=df1, aes(x=education, y=fr_norm)) + 
    geom_line(aes(color="#4040bf"), size = 1) + 
    geom_point(aes(color="#4040bf"),size = 2) + 
    geom_text(aes(label=format(round(fr_norm, 2), nsmall=2), color="#4040bf"), size=3.0, vjust=vpos, hjust=hpos) +
    theme_bw()+ 
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black")) +
    ylab("Normalized Hybrid Fertility Rate")+
    xlab("Years of Schooling") +
    scale_x_continuous(name="Education",
                       breaks=c(0,1,2,3,4),
                       labels=c("< 12", "12", "13-15", "16", "> 16")) +
    ylim(0.6,1.0) +
    scale_color_manual(values=c("#4040bf"),name=" ") +
    scale_shape_manual(values=c(16), name=" ") +  
    theme(legend.position = "none",
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=8.5))
  
  ggsave('Figure15a.pdf',height=2.25, width=3.0) 

  #--------------------------------
  # FR
  #--------------------------------
  
  df3 <- subset(dat, country=="FR")  
  df3$education <- as.numeric(df3$education)
  
  vpos <- c(0.25,-0.75, -0.75, -1, -1)
  hpos <- c(-0.25,-0.25,-0.25,0.25,0.5)

  lineplot <- ggplot(data=df3, aes(x=education, y=fr_norm)) + 
    geom_line(aes(color="#4040bf"), size = 1) + 
    geom_point(aes(color="#4040bf"),size = 2) + 
    geom_text(aes(label=format(round(fr_norm, 2), nsmall=2), color="#4040bf"), size=3.0, vjust=vpos, hjust=hpos) +
    theme_bw()+ 
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black")) +
    ylab("Normalized Hybrid Fertility Rate")+
    xlab("Years of Schooling") +
    scale_x_continuous(name="Education",
                       breaks=c(0,1,2,3,4),
                       labels=c("< 12", "12", "13-15", "16", "> 16")) +
    ylim(0.6,1.0) +
    scale_color_manual(values=c("#4040bf"),name=" ") +
    scale_shape_manual(values=c(16), name=" ") +  
    theme(legend.position = "none",
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=8.5))
  
  ggsave('Figure15b.pdf',height=2.25, width=3.0) 

  
  #--------------------------------
  # IT
  #--------------------------------
  
  df4 <- subset(dat, country=="IT")  
  df4$education <- as.numeric(df4$education)
  
  vpos <- c(0.25,-0.75, -1, -1, -1)
  hpos <- c(-0.25,-0.25,0.5,0.25,0.5)
  
  lineplot <- ggplot(data=df4, aes(x=education, y=fr_norm)) + 
    geom_line(aes(color="#4040bf"), size = 1) + 
    geom_point(aes(color="#4040bf"),size = 2) + 
    geom_text(aes(label=format(round(fr_norm, 2), nsmall=2), color="#4040bf"), size=3.0, vjust=vpos, hjust=hpos) +
    theme_bw()+ 
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black")) +
    ylab("Normalized Hybrid Fertility Rate")+
    xlab("Years of Schooling") +
    scale_x_continuous(name="Education",
                       breaks=c(0,1,2,3,4),
                       labels=c("< 12", "12", "13-15", "16", "> 16")) +
    ylim(0.6,1.0) +
    scale_color_manual(values=c("#4040bf"),name=" ") +
    scale_shape_manual(values=c(16), name=" ") +  
    theme(legend.position = "none",
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=8.5))
  
  ggsave('Figure15c.pdf',height=2.25, width=3.0) 

  
  #--------------------------------
  # ES
  #--------------------------------
  
  df5 <- subset(dat, country=="ES")  
  df5$education <- as.numeric(df5$education)
  
  vpos <- c(0.25,-0.75, -0.75, -1, -1)
  hpos <- c(-0.25,-0.25,-0.25,0.25,0.5)
  
  lineplot <- ggplot(data=df5, aes(x=education, y=fr_norm)) + 
    geom_line(aes(color="#4040bf"), size = 1) + 
    geom_point(aes(color="#4040bf"),size = 2) + 
    geom_text(aes(label=format(round(fr_norm, 2), nsmall=2), color="#4040bf"), size=3.0, vjust=vpos, hjust=hpos) +
    theme_bw()+ 
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black")) +
    ylab("Normalized Hybrid Fertility Rate")+
    xlab("Years of Schooling") +
    scale_x_continuous(name="Education",
                       breaks=c(0,1,2,3,4),
                       labels=c("< 12", "12", "13-15", "16", "> 16")) +
    ylim(0.6,1.0) +
    scale_color_manual(values=c("#4040bf"),name=" ") +
    scale_shape_manual(values=c(16), name=" ") +  
    theme(legend.position = "none",
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=8.5))
  
  ggsave('Figure15d.pdf',height=2.25, width=3.0)
  
  #-------------
  # end of file
  #-------------