/******************************************************************************
 * Figure 16 (right): Disagreement over fertility and mother’s labor market behavior
 ******************************************************************************/

  
* use wave 1 dataset
use "$repo/wave1.dta", clear
drop if missing(alfp_f)

* calculate FLFP for couples with children under age of 3 and all others, then take difference
collapse alfp_f [aweight = aweight2], by(country cc ccf fertrate numsmall)
replace alfp_f = -alfp_f if numsmall == 0
collapse (sum) alfp_f, by(country cc ccf fertrate)

* merge in regular data again and collapse intentions
merge 1:m country using "$repo/wave1.dta", nogenerate
drop if missing(fintent) | missing(mintent)
drop if ankids1 == 0
keep if ageyoungest <= 14

collapse fintent mintent fmintent alfp_f [aweight = aweight2], by(country cc ccf fertrate)

* generate blocking shares in potentials
generate mblock = fintent-fmintent
generate fblock = mintent-fmintent
generate fb_share = fblock/(fblock+mblock+fmintent)
generate mb_share = mblock/(fblock+mblock+fmintent)
generate fmdiff = fb_share-mb_share


* indicator for high fertility country
gen ind = 1
replace ind = 2 if fertrat < 1.7

* keep relevant variables
keep cc ccf fertrat alfp_f fmdiff ind

* save as txt for plotting graph in R
export delimited using "Figure16_right.txt", delimiter(tab) quote replace
