/******************************************************************************
 * IMPORTANT INFORMATION:
 * If you want to generate the relevant data for Figure 17, you need micro data
 * access to the Generations and Gender Program (GGP) micro data. The data can
 * be obtained through the website 
 *    https://www.ggp-i.org
 * where you have to register and apply in order to be able to download the
 * micro data. The only data we use here is wave 1 data. You have to store
 * the wave 1 data files in the folder "81_RAW". 
 * In addition, you will need the micro-data from the ISSP named 
 * ZA5900_v4-0-0.dta, which you can download here:
 *    https://search.gesis.org/research_data/ZA5900
 * Again, you have to put the file into the folder "81_RAW". 
 * When you've downloaded the data, then execute this do-file
 * to generate the data necessary to draw Figure 17. The corresponding
 * R-files will generate the recpective plots.
 ******************************************************************************/


clear all
set maxvar 30000
set more off

* the storage folder for RAW data (copy microdata from https://ggp-i.org here)
global raw = "81_RAW"

* the data output folder
global repo = "82_data_repo"

* set colors
global lcolor = "gs6"
global scolor1 = "midblue"
global scolor2 = "orange_red"
global symb2 = "t"


/******************************************************************************
 * GENERATE THE DATASET NEEDED FOR THE ANALYSIS FROM RAW GGP DATA
 ******************************************************************************/

* recode, select, merge data from raw files of GGP that should be copied to 81_RAW
do "1a_retrieve_wave1_GGP.do"

* recode and select data from raw file of ISSP 2012 that should be copied to 81_RAW
do "1b_retrieve_ISSP_data.do"


/******************************************************************************
 * CREATE DATA FOR FIGURE 17 IN CSV FORMAT
 ******************************************************************************/

* Figure 17 left
do "2a_Figure17_left.do"

* Figure 17 right
do "2b_Figure17_right.do"
