/******************************************************************************
 * Figure 17 (left): Disagreement over fertility and total fertility
 ******************************************************************************/

* use wave 1 dataset
use "$repo/wave1.dta", clear

* drop if data on male or female intentions are missing
drop if missing(fintent) | missing(mintent)

* drop those without children
drop if ankids1 == 0

* only those with children under the age of 14
keep if ageyoungest <= 14

collapse fintent mintent fmintent [aweight = aweight2], by(country cc ccf fertrate)

* generate blocking shares in potentials
generate mblock = fintent-fmintent
generate fblock = mintent-fmintent
generate fb_share = fblock/(fblock+mblock+fmintent)
generate mb_share = mblock/(fblock+mblock+fmintent)
generate fmdiff = fb_share-mb_share

* indicator for high fertility country
gen ind = 1
replace ind = 2 if fertrat < 1.7

* keep relevant variables
keep cc ccf fertrat fmdiff ind

* save as txt for plotting graph in R
export delimited using "Figure_17_left.txt", delimiter(tab) quote replace

