/******************************************************************************
 * Figure 17 (right): Share of Housework and Childcare in ISSP and total fertility
 ******************************************************************************/

use "$repo/ISSP_2012.dta", clear

* recode missings in sex
replace SEX = . if SEX > 2
drop if missing(SEX)

* merge in average TFRs from Worldbank database
merge n:1 ISO using "$repo/WB_tfrav.dta", keepusing(tfrav)
keep if _merge == 3
drop _merge

* select data based on toddlers and partners present
keep if HHTODD >= 1 & HHTODD <= 5
keep if PARTLIV == 1

* recode variable shares
foreach v of varlist V42 V43 V44 V45 V46 V47 {
    drop if `v' > 5 | `v' < 1
    replace `v' = 0.00 if SEX == 2 & `v' == 1
	replace `v' = 0.25 if SEX == 2 & `v' == 2
	replace `v' = 0.50 if SEX == 2 & `v' == 3
	replace `v' = 0.75 if SEX == 2 & `v' == 4
	replace `v' = 1.00 if SEX == 2 & `v' == 5
	
	replace `v' = 1.00 if SEX == 1 & `v' == 1
	replace `v' = 0.75 if SEX == 1 & `v' == 2
	replace `v' = 0.50 if SEX == 1 & `v' == 3
	replace `v' = 0.25 if SEX == 1 & `v' == 4
	replace `v' = 0.00 if SEX == 1 & `v' == 5
}

* calculate total share
gen total_share = (V42 + V44 + V46 + V47)/4

* collapse data according to childcare share and tfr
collapse total_share tfrav [aweight=WEIGHT], by(ISO)

* indicator for high fertility country
gen ind = 1
replace ind = 2 if tfrav < 1.7

* keep relevant variables
keep ISO total_share tfrav ind

* save as txt for plotting graph in R
export delimited using "Figure_17_right.txt", delimiter(tab) quote replace
