  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)

  #------------------------ 
  # Figure 20: ART-infants
  #------------------------ 
  
  setwd("../ReplicationPackage/Figure_20/")
  
  # 1. Load data
  
  dat <- read.table("Figure20.txt", 
                    sep="\t",
                    header = TRUE)
  
  df <- dat %>% filter(
    Country %in% c("Denmark",
                  "Germany",
                  "Italy",
                  "Spain",
                  "United Kingdom",
                  "United States"
    )
  )
 
  df <- subset(df, !is.na(ART_pct)) 
  
  lineplot <- ggplot(data=df, aes(x=Year, y=ART_pct,  colour = Country)) + 
    geom_line(aes(color=Country, linetype=Country), size=1.25) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    )+
    ylab(" ")+
    xlab(" ") +
    scale_color_manual(values=c('#1a476f',
                                '#90353b',	
                                '#55752f',
                                '#e37e00',
                                '#938dd2',
                                '#c10534') , name="") +
    scale_linetype_manual(values=c("dotdash", "longdash", "dotted","dashed", "twodash", "solid") , name="") +
     scale_x_continuous(breaks=c(1997,2000,2003,2006,2009,2012,2015,2018),limits = c(1996,2019),expand = c(0,0))+
    theme(legend.position = "bottom",
          legend.title = element_blank(),
          legend.text = element_text(size=9),
          legend.spacing.x = unit(0.25, 'cm'),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=9, vjust=-1),
          axis.text.y=element_text(size=9),
          axis.title.y=element_text(size=9),
          axis.title.x=element_text(size=9),
          legend.key.width = unit(1.5,"cm")
    )+
    guides(color=guide_legend(nrow=2,byrow=TRUE))
  
  ggsave('Figure20.pdf',height=3.5, width=6)  


  #-------------
  # end of file
  #-------------
