  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  
  #------------ 
  # Figure 21a 
  #------------ 
  
  setwd("../ReplicationPackage/Figure_21/")

  dat <- read.table("Figure21.txt", 
                    sep="\t",
                    header = TRUE)
  
  vpos <- c(-0.25,-0.25,-0.25,-0.75,-0.75, 1.75, 1.25,-0.25,-0.25,-0.25,
             0.75,-0.25, 0.50,-0.75,-0.25,-1.10, 0.75,-0.50, 1.25,-0.60,
            -0.75)
  
  hpos <- c(-0.25,-0.25, 1.25, 0.25, 0.50, 0.25, 1.25, 1.25,-0.25, 1.25,
            -0.25,-0.25,-0.50, 0.60,-0.25, 0.45, 1.25,-0.25,-0.25, 0.75,
            0.75) 

  lineplot <- ggplot(data=dat, aes(x=ECEC, y=TFR)) + 
    geom_point(size=1.5, color="#4040bf") +
    geom_smooth(method=lm, level = 0.9, color="#4040bf", size=1.25,  fill=c("#acace6")) +
    geom_text(aes(label=country, color="#4040bf"), size=2.5, vjust=vpos, hjust=hpos) +
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank())+
    ylab(" ")+
    xlab("Spending (as % of GDP)")+
    scale_color_manual(values=c("#4040bf"), name="") +    
    theme(legend.position = "none",
          legend.title = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9))
  
  ggsave("Figure21a.pdf", height=2.25, width=3.125)
 
  #--------------------------------
  # Figure 21b
  #--------------------------------  

  vpos <- c( 1.25,-0.25,-0.75,-0.75,-1.00, 0.40, 0.75,-0.75, 1.50, 2.00,
             0.75,-0.25, 0.50, 0.50,-0.25,-0.50,-0.75,-0.75, 1.00,-1.25,
            1.75)
  
  hpos <- c(-0.25,-0.25,-0.05, 0.75, 0.25,-0.25, 1.25, 0.50,-0.50, 1.00,
            -0.25,-0.25,-0.50,-0.30,-0.25, 1.25, 0.50, 0.25, 1.25, 0.50,
            0.75)   
    
  lineplot <- ggplot(data=dat, aes(x=ECEC, y=Epop2554)) + 
    geom_point(size=1.5, color="#4040bf") +
    geom_smooth(method=lm, level = 0.9, color="#4040bf", size=1.25,  fill=c("#acace6")) +
    geom_text(aes(label=country, color="#4040bf"), size=2.5, vjust=vpos, hjust=hpos) +
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank())+
    ylab(" ")+
    xlab("Spending (as % of GDP)")+
    scale_color_manual(values=c("#4040bf"), name="") +    
    scale_y_continuous(breaks=c(0.5,0.6,0.7,0.8,0.9), limits = c(0.5,0.9),expand = c(0,0))+
    theme(legend.position = "none",
          legend.title = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9))
  
  ggsave("Figure21b.pdf", height=2.25, width=3.125)
  
   
  #-------------
  # end of file
  #-------------
