  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  library(RColorBrewer)

  #-----------
  # Figure 24
  #-----------
  
  setwd("../ReplicationPackage/Figure_24/")
  
  dat <- read.table("Figure24.txt", 
                    sep="\t",
                    header = TRUE)
  
  dat$country <- factor(dat$country,  levels=c("Finland", "France", "Germany", "Italy", "South Korea", "Spain"))
  
  #--------------------------------
  # By Country 
  #--------------------------------
  
  lineplot <- ggplot(data=dat, aes(x=cohort, y=share0,  colour = country)) + 
    geom_line(aes(color=country, linetype=country), size=1.25) + 
    theme_bw()+  
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Birth Cohort",
                       breaks=c(1,2,3,4,5),
                       labels=c("1930-39","1940-49","1950-59","1960-69","1970-74")) +
    ylim(0,25) +
    scale_color_manual(values=c('#1a476f',
                                '#90353b',	
                                '#55752f',
                                '#e37e00',
                                '#b0b0b0',
                                '#938dd2',
                                '#c10534') , name="") +
    scale_linetype_manual(values=c("dotdash", "longdash", "dotted","dashed", "twodash", "dotdash", "solid") , name="") +
    theme(legend.position = "bottom",
          legend.title = element_blank(),
          legend.text = element_text(size=9),
          legend.spacing.x = unit(0.25, 'cm'),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=9, vjust=0),
          axis.text.y=element_text(size=9),
          axis.title.y=element_text(size=9),
          axis.title.x=element_text(size=9),
          legend.key.width = unit(1.5,"cm")
    )+
    guides(color=guide_legend(nrow=2,byrow=TRUE))
  
  ggsave("Figure24.pdf",height=3.5, width=6)
  
  
  #-------------
  # end of file
  #-------------