  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  library(RColorBrewer)

  #-----------------------------------------------------
  # Figure 25: Completed Cohort Fertility By Education
  #-----------------------------------------------------
  
  setwd("../ReplicationPackage/Figure_25/")
  
  # 1. Load data
  
  dat <- read.table("Figure25.txt", 
                    sep="\t",
                    header = TRUE)
  
  dat$country <- factor(dat$country,  levels=c("Austria", "Finland", "France", "Germany", "Italy", "South Korea", "Spain", "Switzerland"))
  
  #--------------------------------
  # By Country 
  #--------------------------------
  
  dat$edu_cat <- factor(dat$edu_cat, levels=c("1","2","3","4","5","6","7"))
  dat$cohort  <- factor(dat$cohort,  levels=c("1","2","3","4","5","6","7","8","9","10","11"))
  
  #--------------------------------
  # Finland
  #--------------------------------
 
  df1 <- subset(dat, country=="Finland" & cohort %in% c(10))  
  df1$edu_cat <- as.numeric(df1$edu_cat)

  lineplot <- ggplot(data=df1, aes(x=edu_cat, y=share0,  colour = cohort)) + 
    geom_line( ) + 
    geom_point(aes(shape=cohort),size = 2) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Education Group", breaks=c(1,2,3,4,5,6)) +
    ylim(10,35) +
    scale_color_manual(name="", values=c("#4040bf")) +
    scale_shape_manual(values=c(16), name="") +  
    annotate("text", x = 5, y = 35, size = 3, label = c("Cohort 1970-1974"), color="#4040bf")+
    theme(legend.position = "none",
          legend.title = element_blank(),
          legend.text = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9)) 
   
  ggsave("Figure25a.pdf",height=1.75, width=2.75) 

  #--------------------------------
  # France
  #--------------------------------

  df2 <- subset(dat, country=="France" & cohort %in% c(10))  
  df2$edu_cat <- as.numeric(df2$edu_cat)

  lineplot <- ggplot(data=df2, aes(x=edu_cat, y=share0,  colour = cohort)) + 
    geom_line( ) + 
    geom_point(aes(shape=cohort),size = 2) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Education Group", breaks=c(1,2,3,4,5)) +
    ylim(10,35) +
    scale_color_manual(name="", values=c("#4040bf")) +
    scale_shape_manual(values=c(16), name="") +  
    annotate("text", x = 4, y = 35, size = 3, label = c("Cohort 1966-1970"), color="#4040bf")+
    theme(legend.position = "none",
          legend.title = element_blank(),
          legend.text = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9)) 
  
  ggsave("Figure25b.pdf",height=1.75, width=2.75) 

  
  #--------------------------------
  # Germany
  #--------------------------------

  df3 <- subset(dat, country=="Germany" & cohort %in% c(10))
  df3$edu_cat <- as.numeric(df3$edu_cat)

  lineplot <- ggplot(data=df3, aes(x=edu_cat, y=share0,  colour = cohort)) + 
    geom_line( ) + 
    geom_point(aes(shape=cohort),size = 2) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Education Group", breaks=c(1,2,3)) +
    ylim(10,35) +
    scale_color_manual(values=c("#4040bf"),name="") +
    scale_shape_manual(values=c(16), name="") +  
  #  annotate("text", x = 2.5, y = 35, size = 3, label = c("Cohort 1965-1969"), color="#4040bf")+
    theme(legend.position = "none",
          legend.title = element_blank(),
          legend.text = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9)) 
  
  ggsave("Figure25f.pdf",height=1.75, width=2.75) 
  
  
  #--------------------------------
  # Italy
  #--------------------------------

  df4 <- subset(dat, country=="Italy" & cohort %in% c(10))  
  df4$edu_cat <- as.numeric(df4$edu_cat)

  lineplot <- ggplot(data=df4, aes(x=edu_cat, y=share0,  colour = cohort)) + 
    geom_line( ) + 
    geom_point(aes(shape=cohort),size = 2) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Education Group", breaks=c(1,2,3,4)) +
    ylim(10,35) +
    scale_color_manual(values=c("#4040bf"),name="") +
    scale_shape_manual(values=c(16),name="") +  
    annotate("text", x = 3.4, y = 35, size = 3, label = c("Cohort 1966-1968"), color="#4040bf")+
    theme(legend.position = "none",
          legend.title = element_blank(),
          legend.text = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9)) 
  
  ggsave("Figure25c.pdf",height=1.75, width=2.75) 
  
  #--------------------------------
  # Spain
  #--------------------------------

  df6 <- subset(dat, country=="Spain"& cohort %in% c(10)) 
  df6$edu_cat <- as.numeric(df6$edu_cat)
  
  lineplot <- ggplot(data=df6, aes(x=edu_cat, y=share0,  colour = cohort)) + 
    geom_line( ) + 
    geom_point(aes(shape=cohort),size = 2) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=10),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Education Group", breaks=c(1,2,3,4)) +
    ylim(10,35) +
    scale_color_manual(name="", values=c("#4040bf")) +
    scale_shape_manual(values=c(16), name="") + 
    annotate("text", x = 3.4, y = 35, size = 3, label = c("Cohort 1965-1969"), color="#4040bf")+
    theme(legend.position = "none",
          legend.title = element_blank(),
          legend.text = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9)) 
  
  ggsave("Figure25d.pdf",height=1.75, width=2.75) 

  
  #--------------------------------
  # Switzerland
  #--------------------------------

  df7 <- subset(dat, country=="Switzerland"& cohort %in% c(9))
  df7$edu_cat <- as.numeric(df7$edu_cat)

  lineplot <- ggplot(data=df7, aes(x=edu_cat, y=share0,  colour = cohort)) + 
    geom_line( ) + 
    geom_point(aes(shape=cohort),size = 2) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=9),
          axis.title.y=element_blank()
    ) +
    ylab(" ")+
    scale_x_continuous(name="Education Group", breaks=c(1,2,3,4)) +
    ylim(10,35) +
    scale_color_manual(name="", values=c("#4040bf")) +
    scale_shape_manual(values=c(16), name="") + 
    annotate("text", x = 3.4, y = 35, size = 3, label = c("Cohort 1960"), color="#4040bf")+
    theme(legend.position = "none",
          legend.title = element_blank(),
          legend.text = element_blank(),
          axis.title.x=element_text(size=9),
          axis.title.y=element_text(size=9)) 
  
  ggsave("Figure25e.pdf",height=1.75, width=2.75) 
  
  #-------------
  # end of file
  #-------------