  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  library(ggh4x)

  #-------------------------------------------------
  # Figure 27: Living Arrangements of Young Children
  #-------------------------------------------------
  
  setwd("../ReplicationPackage/Figure_27/")
  
  # 1. Load data
  
  dat <- read.table("Figure27.txt", 
                    sep="\t",
                    header = TRUE)
  
  dat$type <- factor(dat$type,  levels=c( "Couple - Married", "Couple - Cohabiting", "Single Mother", "Single Father")) 
  dat$country <- factor(dat$country,  levels=c("France", "Norway", "Belgium", "Sweden", "UK", "USA", "Netherlands", "Spain", "Austria", "Italy",  "Switzerland"))
  
  labels =c("France", "Norway", "Belgium", "Sweden", "UK", "USA", "Netherlands", "Spain", "Austria", "Italy",  "Switzerland")
  
  # 2. Graph
  
  lineplot <- ggplot(data=dat, mapping=aes(x=as.numeric(country), y=percentage, fill=type)) + 
    geom_bar(stat="identity", position = "dodge")  + 
    theme(panel.spacing = unit(0, "lines"), 
          strip.background = element_blank(),
          axis.title.y=element_blank(),
    ) +
    theme_bw()+
    ylab("Fraction of Children Age 0-5")+
    xlab("")+
    scale_fill_manual(values = c("#0000FF", "#9999FF", "#FF0000", "#FF9999"), name="") +
    scale_x_continuous(breaks = 1:length(labels), labels = labels) +
    theme(legend.title = element_blank(),
          legend.text = element_text(size=8,margin = margin(r = 15, unit = "pt")),
          legend.position = "bottom",
          axis.text.x = element_text(size=7, vjust=-1),
          axis.text.y=element_text(size=9),
          axis.title.y=element_text(size=9),
          axis.title.x=element_text(size=9),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"))
  
  
  ggsave("Figure27.pdf", height=3.5, width=6)  

    #-------------
  # end of file
  #-------------
