  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  library(ggh4x)

  #------------------------------------------------------------
  # Figure 28: Fraction of Children living with Single Mothers
  #------------------------------------------------------------
  
  setwd("../ReplicationPackage/Figure_28/")
  
  # 1. Load data
  
  dat <- read.table("Figure28.txt", 
                    sep="\t",
                    header = TRUE)
  
  dat$edu <- factor(dat$edu,  levels=c( "Low Education", "Medium Education", "High Education")) 
  dat$country <- factor(dat$country,  levels=c("Switzerland", "Italy", "Austria", "Spain", "Netherlands", "France", "Sweden", "Belgium", "UK", "USA", "Norway"))
  
  labels =c("Switzerland", "Italy", "Austria", "Spain", "Netherlands", "France", "Sweden", "Belgium", "UK", "USA", "Norway")
  
  # 2. Graph
  
  lineplot <- ggplot(data=dat, mapping=aes(x=as.numeric(country), y=single_mom, fill=edu)) + 
    geom_bar(stat="identity", position = "dodge")  + 
    theme(panel.spacing = unit(0, "lines"), 
          strip.background = element_blank(),
          axis.title.y=element_blank(),
    ) +
    theme_bw()+
    ylab("Fraction of Children Age 0-17")+
    xlab("")+
    scale_fill_manual(values = c("#0000FF", "#9999FF", "#FF0000"), name="") +
    scale_x_continuous(breaks = 1:length(labels), labels = labels) +
    theme(legend.title = element_blank(),
          legend.text = element_text(size=8,margin = margin(r = 25, unit = "pt")),
          legend.position = "bottom",
          axis.text.x = element_text(size=7.0, vjust=-1),
          axis.text.y=element_text(size=9),
          axis.title.y=element_text(size=9),
          axis.title.x=element_text(size=9),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"))
  
  
  ggsave("Figure28.pdf",height=3.5, width=6)  
  
  #-------------
  # end of file
  #-------------
