


use "../ReplicationPackage/Figure_29/atus-ipums.dta", replace

* 1. Sample restrictions
drop if spousepres!=1 & spousepres!=2 	// Keep only respondents with spouse or unmarried partner living in the household
drop if age>55 | age<25					// Keep individuals between ages 25 and 55
drop if hh_child!=1						// Keep only households with at least one child
drop if hh_numadults!=2					// Keep households with exactly 2 adults
drop if speduc==998 | speduc==999		// Keep only if education level of spouse is available
drop if year>2019						// Only consider data up to 2019

* 2. Employment type definitions
* Respondent
gen unemployed=0 if empstat==1 | empstat==2
replace unemployed=1 if empstat==3 | empstat==4 | empstat==5
gen FTPT=0 if fullpart==1 & unemployed==0 						// full time
replace FTPT=1 if fullpart==2 & unemployed==0 					// part time
replace FTPT=2 if unemployed==1									// employment status = unemployed/not in LF

* Spouse
gen FTPT_sp=0 if fullpart_sp==1 & spempnot==1 					// full time
replace FTPT_sp=1 if fullpart_sp==2 & spempnot==1 				// part time
replace FTPT_sp=2 if spempnot==0 								// employment status = not employed

* Using spousal usual working hours on main job to define FTPT_sp
* FT definition in ATUS: >=35 hours
replace FTPT_sp=0 if spusualhrs>=35 & spusualhrs!=995 & spusualhrs!=999 & spusualhrs!=.
replace FTPT_sp=1 if spusualhrs<35 & spusualhrs!=.
replace FTPT_sp=3 if spusualhrs==995 // Hours vary

* 3. Generate by sex and employment type childcare time
forval x=0/2 {
		gen bls_carehh_kid_`x'=bls_carehh_kid if FTPT==`x'
	}
collapse bls_carehh_kid_0 bls_carehh_kid_1 bls_carehh_kid_2 [pw= wt06], by(sex)
label var bls_carehh_kid_0 "Full time"
label var bls_carehh_kid_1 "Part time"
label var bls_carehh_kid_2 "Not employed"

reshape long bls_carehh_kid_, i(sex) j(emp_status)  
 
rename bls_carehh_kid_ bls_carehh_kid
label var bls_carehh_kid "Weekly Childcare (in minutes per day)"
rename sex parent
label var parent "Parent"
label var emp_status "Employment Status"

label define emp_status_l 0 `"Full-time"' 1 `"Part-time"' 2 `"Non-employed"'
label values emp_status emp_status_l

label define parent_l 1 `"Fathers"' 2 `"Mothers"'
label values parent parent_l

outsheet using "../ReplicationPackage/Figure_29/Figure29.txt", replace


