* ---------------------------------------------------------------------------- *
* 					Time Use by Education - MTUS HAF	 		 			   *
* ---------------------------------------------------------------------------- *
* author: 		 Anne Hannusch
* last modified: 2022-01-26

* This code computes time use childcare among women 20-55, 
* pooling MTUS waves between 2004 and 2018
 

* Input file:  mtus_00001.dta  (download from IPUMS and save in $PATH)
* Output file: Figure30.txt

* ---------------------------------------------------------------------------- *

clear all
set more off

* Set file path - LINUX/OS
global PATH   = "../ReplicationPackage/Figure_30/"

use "${PATH}ALL_HAF_external.dta", replace

* ---------------------------------------------------------------------------- *
* A. Select Sample												    		   *
* ---------------------------------------------------------------------------- *

keep if age>=18 & age<=45
keep if sex==1|sex==2

gen chage_below12=0
replace chage_below12=1 if agekidx>0 & agekidx<=2
replace chage_below12=1 if agekid2>0 & agekid2<=12 // keep if youngest child < 12
drop if chage_below12==0

* ---------------------------------------------------------------------------- *
* B. Create Variables		     								    		   *
* ---------------------------------------------------------------------------- *

gen partnered=.
replace partnered=0 if civstat==2
replace partnered=1 if civstat==1

gen edu_cat=.
replace edu_cat=1 if edcat==1
replace edu_cat=1 if edcat==2
replace edu_cat=2 if edcat==3

label define lab_edu 1 "low" 2 "high"
label values edu_cat lab_edu

gen weight = propwt // population & day combined weight rescaled if needed

gen kidcare = pkidcare+ikidcare

* ---------------------------------------------------------------------------- *
* C. Summary Stats												    		   *
* ---------------------------------------------------------------------------- *

keep if partnered==1

egen newid=group(sex edu_cat)
label define lab_newid 1 "Men - low" 2 "Men - high" 3 "Women - low" 4 "Women - high"
label values newid lab_newid

collapse (mean) pkidcare ikidcare kidcare [aw=weight], by(country year newid)
 
bys country year: gen N=_N
bys country year: egen N_max=max(N)
bys country: egen year_max=max(year)

keep if N==N_max & year==year_max

drop N_max
drop year_max
drop N
 
drop if newid==.
 
outsheet using "${PATH}Figure30.txt", replace
 
* ---------------------------------------------------------------------------- *
* 								end of do-file	 							   *
* ---------------------------------------------------------------------------- *
