* Figure 31 
/* 
 The general layout of the file is to run regressions for each country
 and each gender separately, creating the country data files, 
 then combine them at the end and make the graph. 
 Estimates for US mothers are annotated and the estimates for 
 other countries and for fathers follow the same methodology. 
 

 
 The graphing begins around line 434 of the file. 
*/
 
global PATH  = "../ReplicationPackage/Figure_31/"

set more off

use "${PATH}smallmaster.dta", clear // dataset containing time use data from ATUS, MTUS, GSS

* Label all variables in the database
lab var countrya "numeric country id"
lab var year "year"
lab var propwt "survey weight"
lab var country "country"
lab var above2ndedu "college/no college"
label def yn_labs 1 "Yes" 0 "No"
label values above2ndedu yn_labs
* the mainXX variables follow MTUS codes: https://www.timeuse.org/sites/default/files/9727/chapter-3-activity-codes.pdf
lab var main28 "time spent on physical or medical care, hrs/week" 
lab var main29 "time spent on homework/teach child a skill, hrs/week" 
lab var main30 "time spent reading/talking/playing with child, hrs/week" 
lab var main31 "supervise/accompany/other child care, hrs/week"
lab var childtot "total time spend on childcare, hrs/week, main28+main29+main30+main31"
lab var agecat "age category"
label def age_labs 1 "18-24" 2 "25-34" 3 "35-44" 4 "45-54" 5 "55-64"
label values agecat age_labs
lab var mother "mother"
lab values mother yn_labs
lab var father "father"
lab values father yn_labs

*===============================================================================
*====================================USA========================================
*===============================================================================

use "${PATH}smallmaster.dta", clear
keep if country=="USA"

*==========================MOTHERS==============================================

* define the omitted dummy categories for the regressions:
char year[omit] 1992 
char above2ndedu[omit] 1
char agecat[omit] 2 

* run the regression with interactions for years and education level for mothers:
xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if mother==1

* obtain predictions based on covariates and regression results:
predict b if e(sample)

* separate the individuals of interest, namely educated/non-educated 25-34 y.o mothers
gen nonedu_mother = b if agecat==2 & above2ndedu==0
gen edu_mother = b if agecat==2 & above2ndedu==1

drop b

sort year

/* Create individual weights that will be used to compute total time for 
educ/non-educ together: "all_mother" below
*/

gen sex =.
replace sex =1 if mother == 1
replace sex =2 if father == 1

gen weight_edu=.
gen n=1
bys year above2ndedu sex: egen total=sum(n)
bys year sex:egen total2=sum(n)
replace weight_edu=mother*total/total2 if edu_mother ~=.  //only mother
replace weight_edu=1-mother*total/total2 if nonedu_mother ~=.

bys year: egen edu_mother_max=max(edu_mother)
bys year: egen nonedu_mother_max=max(nonedu_mother)
gen all_mother=edu_mother_max*weight_edu+nonedu_mother_max*(1-weight_edu)

label var all_mother "Mothers"
	
*==========================FATHERS==============================================

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if father==1

predict b if e(sample)

gen nonedu_father = b if agecat==2 & above2ndedu==0
gen edu_father = b if agecat==2 & above2ndedu==1

drop b

sort year 

label var edu_father "college"
label var nonedu_father "less than college"
	

replace weight_edu=father*total/total2 if edu_father ~=.  //only father
replace weight_edu=1-father*total/total2 if nonedu_father ~=.

bys year: egen edu_father_max=max(edu_father)
bys year: egen nonedu_father_max=max(nonedu_father)
gen all_father=edu_father_max*weight_edu+nonedu_father_max*(1-weight_edu)

label var all_father "Fathers"

* save the data for the US:
keep country year all_father all_mother
save "${PATH}usa.dta",replace	
	
*===============================================================================
*===============================SPAIN===========================================
*===============================================================================

use "${PATH}smallmaster.dta", clear
keep if country=="Spain"

*==========================MOTHERS==============================================

char year[omit] 1992
char above2ndedu[omit] 1
char agecat[omit] 2

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if mother==1

predict b if e(sample)

gen nonedu_mother = b if agecat==2 & above2ndedu==0
gen edu_mother = b if agecat==2 & above2ndedu==1

drop b

sort year 
	
gen sex =.
replace sex =1 if mother == 1
replace sex =2 if father == 1

gen weight_edu=.
gen n=1
bys year above2ndedu sex: egen total=sum(n)
bys year sex:egen total2=sum(n)
replace weight_edu=mother*total/total2 if edu_mother ~=.  //only mother
replace weight_edu=1-mother*total/total2 if nonedu_mother ~=.

bys year: egen edu_mother_max=max(edu_mother)
bys year: egen nonedu_mother_max=max(nonedu_mother)
gen all_mother=edu_mother_max*weight_edu+nonedu_mother_max*(1-weight_edu)
	
*==========================FATHERS==============================================

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if father==1

predict b if e(sample)

gen nonedu_father = b if agecat==2 & above2ndedu==0
gen edu_father = b if agecat==2 & above2ndedu==1

drop b

sort year 
	
replace weight_edu=father*total/total2 if edu_father ~=.  //only father
replace weight_edu=1-father*total/total2 if nonedu_father ~=.

bys year: egen edu_father_max=max(edu_father)
bys year: egen nonedu_father_max=max(nonedu_father)
gen all_father=edu_father_max*weight_edu+nonedu_father_max*(1-weight_edu)

*********
keep country year all_father all_mother
save "${PATH}spain.dta",replace

*===============================================================================
*==========================NETHERLAND===========================================
*===============================================================================

use "${PATH}smallmaster.dta", clear
keep if country=="Netherland"

*==========================MOTHERS==============================================

char year[omit] 1990
char above2ndedu[omit] 1
char agecat[omit] 2

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if mother==1

predict b if e(sample)

gen nonedu_mother = b if agecat==2 & above2ndedu==0
gen edu_mother = b if agecat==2 & above2ndedu==1

drop b

sort year 
	
gen sex =.
replace sex =1 if mother == 1
replace sex =2 if father == 1

gen weight_edu=.
gen n=1
bys year above2ndedu sex: egen total=sum(n)
bys year sex:egen total2=sum(n)
replace weight_edu=mother*total/total2 if edu_mother ~=.  //only mother
replace weight_edu=1-mother*total/total2 if nonedu_mother ~=.

bys year: egen edu_mother_max=max(edu_mother)
bys year: egen nonedu_mother_max=max(nonedu_mother)
gen all_mother=edu_mother_max*weight_edu+nonedu_mother_max*(1-weight_edu)

*==========================FATHERS==============================================

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if father==1

predict b if e(sample)

gen nonedu_father = b if agecat==2 & above2ndedu==0
gen edu_father = b if agecat==2 & above2ndedu==1

drop b

sort year 

replace weight_edu=father*total/total2 if edu_father ~=.  //only father
replace weight_edu=1-father*total/total2 if nonedu_father ~=.

bys year: egen edu_father_max=max(edu_father)
bys year: egen nonedu_father_max=max(nonedu_father)
gen all_father=edu_father_max*weight_edu+nonedu_father_max*(1-weight_edu)
	
*********
keep country year all_father all_mother
save "${PATH}netherlands.dta",replace
	
*===============================================================================
*===============================ITALY===========================================
*===============================================================================

use "${PATH}smallmaster.dta", clear
keep if country=="Italy"

*==========================MOTHERS==============================================

char year[omit] 1989
char above2ndedu[omit] 1
char agecat[omit] 2

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if mother==1

predict b if e(sample)

gen nonedu_mother = b if agecat==2 & above2ndedu==0
gen edu_mother = b if agecat==2 & above2ndedu==1

drop b

sort year 

gen sex =.
replace sex =1 if mother == 1
replace sex =2 if father == 1

gen weight_edu=.
gen n=1
bys year above2ndedu sex: egen total=sum(n)
bys year sex:egen total2=sum(n)
replace weight_edu=mother*total/total2 if edu_mother ~=.  //only mother
replace weight_edu=1-mother*total/total2 if nonedu_mother ~=.

bys year: egen edu_mother_max=max(edu_mother)
bys year: egen nonedu_mother_max=max(nonedu_mother)
gen all_mother=edu_mother_max*weight_edu+nonedu_mother_max*(1-weight_edu)

*==========================FATHERS==============================================

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if father==1

predict b if e(sample)

gen nonedu_father = b if agecat==2 & above2ndedu==0
gen edu_father = b if agecat==2 & above2ndedu==1

drop b

sort year 

replace weight_edu=father*total/total2 if edu_father ~=.  //only father
replace weight_edu=1-father*total/total2 if nonedu_father ~=.

bys year: egen edu_father_max=max(edu_father)
bys year: egen nonedu_father_max=max(nonedu_father)
gen all_father=edu_father_max*weight_edu+nonedu_father_max*(1-weight_edu)
	
*********
keep country year all_father all_mother
save "${PATH}italy.dta",replace	
*===============================================================================
*===============================CANADA==========================================
*===============================================================================

use "${PATH}smallmaster.dta", clear
keep if country=="Canada"

*==========================MOTHERS==============================================

char year[omit] 1992
char above2ndedu[omit] 1
char agecat[omit] 2

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if mother==1

predict b if e(sample)

gen nonedu_mother = b if agecat==2 & above2ndedu==0
gen edu_mother = b if agecat==2 & above2ndedu==1

drop b

sort year 

gen sex =.
replace sex =1 if mother == 1
replace sex =2 if father == 1

gen weight_edu=.
gen n=1
bys year above2ndedu sex: egen total=sum(n)
bys year sex:egen total2=sum(n)
replace weight_edu=mother*total/total2 if edu_mother ~=.  //only mother
replace weight_edu=1-mother*total/total2 if nonedu_mother ~=.

bys year: egen edu_mother_max=max(edu_mother)
bys year: egen nonedu_mother_max=max(nonedu_mother)
gen all_mother=edu_mother_max*weight_edu+nonedu_mother_max*(1-weight_edu)

*==========================FATHERS==============================================

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if father==1

predict b if e(sample)

gen nonedu_father = b if agecat==2 & above2ndedu==0
gen edu_father = b if agecat==2 & above2ndedu==1

drop b

sort year 
	
replace weight_edu=father*total/total2 if edu_father ~=.  //only father
replace weight_edu=1-father*total/total2 if nonedu_father ~=.

bys year: egen edu_father_max=max(edu_father)
bys year: egen nonedu_father_max=max(nonedu_father)
gen all_father=edu_father_max*weight_edu+nonedu_father_max*(1-weight_edu)
	
*********
keep country year all_father all_mother
save "${PATH}canada.dta",replace	
	
*===============================================================================
*===============================UK==========================================
*===============================================================================

use "${PATH}smallmaster.dta", clear
keep if country=="UK"

*==========================MOTHERS==============================================

char year[omit] 1983
char above2ndedu[omit] 1
char agecat[omit] 2

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if mother==1

predict b if e(sample)

gen nonedu_mother = b if agecat==2 & above2ndedu==0
gen edu_mother = b if agecat==2 & above2ndedu==1

drop b

sort year 
	
gen sex =.
replace sex =1 if mother == 1
replace sex =2 if father == 1

gen weight_edu=.
gen n=1
bys year above2ndedu sex: egen total=sum(n)
bys year sex:egen total2=sum(n)
replace weight_edu=mother*total/total2 if edu_mother ~=.  //only mother
replace weight_edu=1-mother*total/total2 if nonedu_mother ~=.

bys year: egen edu_mother_max=max(edu_mother)
bys year: egen nonedu_mother_max=max(nonedu_mother)
gen all_mother=edu_mother_max*weight_edu+nonedu_mother_max*(1-weight_edu)

*==========================FATHERS==============================================

xi:reg childtot i.year*above2ndedu i.agecat [aw=propwt] if father==1

predict b if e(sample)

gen nonedu_father = b if agecat==2 & above2ndedu==0
gen edu_father = b if agecat==2 & above2ndedu==1

drop b

sort year 
	
replace weight_edu=father*total/total2 if edu_father ~=.  //only father
replace weight_edu=1-father*total/total2 if nonedu_father ~=.

bys year: egen edu_father_max=max(edu_father)
bys year: egen nonedu_father_max=max(nonedu_father)
gen all_father=edu_father_max*weight_edu+nonedu_father_max*(1-weight_edu)

*********
keep country year all_father all_mother
save "${PATH}uk.dta",replace

************************************************
*FIGURE:  Double panels fathers mothers

* First append country files together
use "${PATH}usa.dta",clear

append using "${PATH}spain.dta"
append using "${PATH}netherlands.dta"
append using "${PATH}italy.dta"
append using "${PATH}canada.dta"
append using "${PATH}uk.dta"

drop if year<1975

* For each country-yer pair, compute the mean time for mothers and for fathers. 
* The numbers in the text are based on these series. 
collapse all_father all_mother, by (country year) 	

outsheet using "${PATH}Figure31.txt", replace

rm "${PATH}spain.dta"
rm "${PATH}netherlands.dta"
rm "${PATH}italy.dta"
rm "${PATH}canada.dta"
rm "${PATH}uk.dta"
rm "${PATH}usa.dta"
