* Figure 32
clear all
set more off

global PATH  = "..."

set more off

use "${PATH}TimeUse_USA.dta", clear // time use data from ATHUS

* CREATE FIGURES - REGRESSION APPROACH
* See Ramey & Ramey (2010) p 133-134 for details on regression
/* The general approach is to run regressions to calculate conditional
means for mothers and fathers separately and use an interaction term with
time and education to compute high school and college separately, then
save them in a matrix, and plot them. Data is for ages 25-34.
Mother code is annotated more heavily and father code follows same approach
*/

* Omitted Groups (means are relative to these groups):
* Survey year: 1975
* Less than College Education
* Age Category 25-34

* Generate Age Bin Dummies
gen agecat=1 if age>=18 & age<=24
replace agecat=2 if age>=25 & age<=34
replace agecat=3 if age>=35 & age<=44
replace agecat=4 if age>=45 & age<=54
replace agecat=5 if age>=55 & age<=64

* Set omitted 
char dataset[omit] 1975
char college[omit] 0
char agecat[omit] 2

label var dataset "Year"

drop if stud==1 // Omit Students from Analysis -- unclear what to do for missing student identifiers, many in 1995 survey
* NOTE: I keep students with missing student status, which accounts for about 5,000 observations

* Regression for mothers: 
xi:reg childtot i.dataset*college i.agecat [aw=recwght] if mother==1
mat beta_mother = e(b) // save coeffs for plotting
svmat double beta_mother, names(mcoefs)

* Regression for fathers:
xi:reg childtot i.dataset*college i.agecat [aw=recwght] if father==1
mat beta_father = e(b)
svmat double beta_father, names(fcoefs)

* Plot Results
scalar ncoefs = e(df_m)+1 // number of coefficients, used in creating plot series 
local ncoefs = e(df_m)+1
di scalar(ncoefs)

* Create Plotting Series (time, and four categories):
gen cc_years            = .
gen cc_mother_nocollege = . 
gen cc_mother_college   = . 
gen cc_father_nocollege = .
gen cc_father_college   = .

* Fill Down Coef Vectors
forvalues i = 1/`ncoefs' {
replace mcoefs`i' = mcoefs`i'[_n-1] if _n>1
replace fcoefs`i' = fcoefs`i'[_n-1] if _n>1
}
*

* Plotting Years (these are the years time use data is available)
replace cc_years = 1965 if _n==1
replace cc_years = 1975 if _n==2
replace cc_years = 1985 if _n==3
replace cc_years = 1993 if _n==4
replace cc_years = 1995 if _n==5
replace cc_years = 1998 if _n==6
replace cc_years = 2000 if _n==7
replace cc_years = 2003 if _n==8
replace cc_years = 2004 if _n==9
replace cc_years = 2005 if _n==10
replace cc_years = 2006 if _n==11
replace cc_years = 2007 if _n==12
replace cc_years = 2008 if _n==13
replace cc_years = 2009 if _n==14
replace cc_years = 2010 if _n==15
replace cc_years = 2011 if _n==16
replace cc_years = 2012 if _n==17


* Mothers without College
replace cc_mother_nocollege = mcoefs38 + mcoefs1 if _n==1 // constant plus year effect (1965)
replace cc_mother_nocollege = mcoefs38 + 0       if _n==2 // constant only because comparison year (1975)
replace cc_mother_nocollege = mcoefs38 + mcoefs2 if _n==3 // constant plus year effect (1985)
replace cc_mother_nocollege = mcoefs38 + mcoefs3 if _n==4
replace cc_mother_nocollege = mcoefs38 + mcoefs4 if _n==5
replace cc_mother_nocollege = mcoefs38 + mcoefs5 if _n==6
replace cc_mother_nocollege = mcoefs38 + mcoefs6 if _n==7
replace cc_mother_nocollege = mcoefs38 + mcoefs7 if _n==8
replace cc_mother_nocollege = mcoefs38 + mcoefs8 if _n==9
replace cc_mother_nocollege = mcoefs38 + mcoefs9 if _n==10
replace cc_mother_nocollege = mcoefs38 + mcoefs10 if _n==11
replace cc_mother_nocollege = mcoefs38 + mcoefs11 if _n==12
replace cc_mother_nocollege = mcoefs38 + mcoefs12 if _n==13
replace cc_mother_nocollege = mcoefs38 + mcoefs13 if _n==14
replace cc_mother_nocollege = mcoefs38 + mcoefs14 if _n==15
replace cc_mother_nocollege = mcoefs38 + mcoefs15 if _n==16 
replace cc_mother_nocollege = mcoefs38 + mcoefs16 if _n==17 // 2012

* Mothers with College
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs18 if _n==1 // noncollege effect plus college effect plus college-year (1965)
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + 0        if _n==2 // noncollege effect plus college effect (1975)
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs19 if _n==3 // noncollege effect plus college effect plus college-year (1985)
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs20 if _n==4
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs21 if _n==5
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs22 if _n==6
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs23 if _n==7
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs24 if _n==8
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs25 if _n==9
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs26 if _n==10
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs27 if _n==11
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs28 if _n==12
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs29 if _n==13
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs30 if _n==14
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs31 if _n==15
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs32 if _n==16 
replace cc_mother_college = cc_mother_nocollege +mcoefs17 + mcoefs33 if _n==17 // 2012

* Fathers without College
replace cc_father_nocollege = fcoefs38 + fcoefs1 if _n==1 //1965
replace cc_father_nocollege = fcoefs38 + 0       if _n==2
replace cc_father_nocollege = fcoefs38 + fcoefs2 if _n==3
replace cc_father_nocollege = fcoefs38 + fcoefs3 if _n==4
replace cc_father_nocollege = fcoefs38 + fcoefs4 if _n==5
replace cc_father_nocollege = fcoefs38 + fcoefs5 if _n==6
replace cc_father_nocollege = fcoefs38 + fcoefs6 if _n==7
replace cc_father_nocollege = fcoefs38 + fcoefs7 if _n==8
replace cc_father_nocollege = fcoefs38 + fcoefs8 if _n==9
replace cc_father_nocollege = fcoefs38 + fcoefs9 if _n==10
replace cc_father_nocollege = fcoefs38 + fcoefs10 if _n==11
replace cc_father_nocollege = fcoefs38 + fcoefs11 if _n==12
replace cc_father_nocollege = fcoefs38 + fcoefs12 if _n==13
replace cc_father_nocollege = fcoefs38 + fcoefs13 if _n==14
replace cc_father_nocollege = fcoefs38 + fcoefs14 if _n==15
replace cc_father_nocollege = fcoefs38 + fcoefs15 if _n==16 
replace cc_father_nocollege = fcoefs38 + fcoefs16 if _n==17 // 2012

* Fathers with College
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs18 if _n==1 //1965
replace cc_father_college = cc_father_nocollege +fcoefs17 + 0        if _n==2
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs19 if _n==3
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs20 if _n==4
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs21 if _n==5
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs22 if _n==6
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs23 if _n==7
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs24 if _n==8
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs25 if _n==9
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs26 if _n==10
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs27 if _n==11
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs28 if _n==12
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs29 if _n==13
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs30 if _n==14
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs31 if _n==15
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs32 if _n==16 
replace cc_father_college = cc_father_nocollege +fcoefs17 + fcoefs33 if _n==17 // 2012

keep cc_* 
drop if cc_year==.
 

outsheet using "${PATH}Figure32.txt", replace
