  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)

  #--------------------------------
  # Completed Cohort Fertility
  #--------------------------------
  
  setwd("../ReplicationPackage/Figure_A4/")
  
  # 1. Load data
  
  dat <- read.table("FigureA4.txt", 
                    sep="\t",
                    header = TRUE)

  #---------------------------------------------
  # Finland, France, Germany, Italy, Spain, USA
  #---------------------------------------------

  df <- dat %>%
    select(COHORT, Finland, France, Germany, Italy, Austria, Spain, USA) %>%
    gather(key = "variable", value = "value", -COHORT)
    df[, c(1,3)] <- sapply(df[, c(1,3)], as.numeric) 

  lineplot <- ggplot(data=df, aes(x=COHORT, y=value,  colour = variable)) + 
    geom_line( size=1.25) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.title.x=element_text(size=10),
          axis.title.y=element_blank()
    )+
    xlab("Birth Cohort") +
    xlim(c(1940,1975)) +
    ylim(1.4,2.8) +
    scale_color_manual(values=c('#cac27e',
                                '#6e8e84',
                                '#e37e00',
                                '#938dd2',
                                '#006000',
                                '#1a476f',
                                '#c10534'),name="", labels = c("Finland", "France", "Germany", "Italy", "Austria", "Spain", "USA")) +
    theme(legend.position = "bottom",
          legend.title = element_blank(),
          axis.title.y=element_blank(),
          axis.title.x=element_text(size=10))+
    guides(col = guide_legend(nrow = 1))
 
  ggsave('FigureA4.pdf',height=3.5, width=5)

  #-------------
  # end of file
  #-------------
