  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  
  #-------------------------------------
  # Figure A5 a: Hybrid Fertility Rates
  #-------------------------------------
  
  setwd("../ReplicationPackage/Figure_A5/")
  
  # 1. Load data
  
  dat <- read.table("FigureA5_a.txt", 
                    sep="\t",
                    header = TRUE)
 
  dat$group <- factor(dat$group,  levels=c("0","1","2","3","4"))
  dat$year <- factor(dat$year,  levels=c("1980","1990","2000","2010","2019"))
  
  dat$group <- as.numeric(dat$group)
   
  lineplot <- ggplot(data=dat, aes(x=group, y=fr,  colour = year)) + 
    geom_line(aes(linetype=year),size=1.0) + 
    geom_point(aes(shape=year),size = 2.75) + 
    theme_bw()+
    theme(panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black")
    ) +
    ylab("Normalized Hybrid Fertility Rate")+
    xlab("Years of Schooling") +
    ylim(c(1,3))+
    scale_x_continuous(labels=c("$<$ 12", "12", "13-15", "16", "$>$16")) +
    scale_color_manual(values=c('#1a476f',
                                '#6e8e84',
                                '#e37e00',
                                '#006000',
                                '#c10534'),name="", labels = c("1980", "1990","2000", "2010", "2019")) +
    scale_shape_manual(values=c(15,18,8,17,19) , name="", labels = c("1980", "1990","2000", "2010", "2019"))  +  
    scale_linetype_manual(values=c("longdash", "dotted", "dotdash","dashed", "solid") , name="", labels = c("1980", "1990","2000", "2010", "2019")) +
    theme(legend.position=c(0.7,0.75),
          legend.title = element_blank(),
          legend.text = element_text(size=7),
          legend.spacing.y = unit(-.5, 'cm'),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=9),
          axis.text.y=element_text(size=9),
          axis.title.y=element_text(size=8.5),
          axis.title.x=element_text(size=9),
          legend.key.width = unit(0.85,"cm"),
          legend.margin=margin(0,0,0,0),
          legend.box.margin=margin(-2,-2,-2,-2)
    )+
    guides(color=guide_legend(ncol=2))
  
   ggsave("FigureA5_a.pdf",height=2.25, width=3.0)

  #-------------
  # end of file
  #-------------
